@@ -64,7 +64,8 @@ typedef enum {
   hmat_compress_aca_full,
   hmat_compress_aca_partial,
   hmat_compress_aca_plus,
-  hmat_compress_aca_random
+  hmat_compress_aca_random,
+  hmat_compress_rrqr
 } hmat_compress_t;
 
 typedef enum {
@@ -372,6 +373,7 @@ HMAT_API hmat_compression_algorithm_t* hmat_create_compression_aca_full(double e
 HMAT_API hmat_compression_algorithm_t* hmat_create_compression_aca_partial(double epsilon);
 HMAT_API hmat_compression_algorithm_t* hmat_create_compression_aca_plus(double epsilon);
 HMAT_API hmat_compression_algorithm_t* hmat_create_compression_aca_random(double epsilon);
+HMAT_API hmat_compression_algorithm_t* hmat_create_compression_rrqr(double epsilon);
 
 /* Delete a compression algorithm */
 HMAT_API void hmat_delete_compression(const hmat_compression_algorithm_t* algo);
@@ -1003,6 +1005,8 @@ typedef struct
   int validateNullRowCol;
   /*! \brief Validate the rk-matrices after compression */
   int validateCompression;
+  /*! \brief Validate the rk-matrices recompression */
+  int validateRecompression;
   /*! \brief Dump trace at the end of the algorithms (depends on the runtime) */
   int dumpTrace;
   /*! \brief For blocks above error threshold, re-run the compression algorithm */
