@@ -199,8 +199,8 @@ int full_gemm(char transA, char transB, int mc, int nc, void* c,
 }
 
 template<typename T, template <typename> class E>
-int gemm(char trans_a, char trans_b, void *alpha, hmat_matrix_t * holder,
-                   hmat_matrix_t * holder_b, void *beta, hmat_matrix_t * holder_c) {
+int gemm(char trans_a, char trans_b, const void *alpha, hmat_matrix_t * holder,
+         hmat_matrix_t * holder_b, const void *beta, hmat_matrix_t * holder_c) {
   DECLARE_CONTEXT;
   hmat::HMatInterface<T>* hmat_a = (hmat::HMatInterface<T>*)holder;
   hmat::HMatInterface<T>* hmat_b = (hmat::HMatInterface<T>*)holder_b;
@@ -299,8 +299,8 @@ inline char switch_flag_conj(char trans) {
 }
 
 template<typename T, template <typename> class E>
-int gemm_dense(char trans_b, char trans_x, char side, void* alpha, hmat_matrix_t* holder,
-               void* vec_x, void* beta, void* vec_y, int nrhs) {
+int gemm_dense(char trans_b, char trans_x, char side, const void* alpha, hmat_matrix_t* holder,
+               void* vec_x, const void* beta, void* vec_y, int nrhs) {
   char trans_y = 'N';
   T alphaT = *((T*)alpha);
   T betaT = *((T*)beta);
@@ -411,7 +411,20 @@ int init() {
 template<typename T, template <typename> class E>
 double norm(hmat_matrix_t* holder) {
   DECLARE_CONTEXT;
-  return ((hmat::HMatInterface<T>*)holder)->norm();
+  return reinterpret_cast<hmat::HMatInterface<T>*>(holder)->engine().norm();
+}
+
+template<typename T, template <typename> class E>
+int logdet(hmat_matrix_t* holder, double * result) {
+  DECLARE_CONTEXT;
+  try {
+    auto r = reinterpret_cast<hmat::HMatInterface<T>*>(holder)->engine().logdet();
+    *reinterpret_cast<typename hmat::Types<T>::dp*>(result)=r;
+  } catch (const std::exception& e) {
+      fprintf(stderr, "%s\n", e.what());
+      return 1;
+  }
+  return 0;
 }
 
 template<typename T, template <typename> class E>
@@ -687,6 +700,9 @@ int get_block(struct hmat_get_values_context_t *ctx) {
   DISABLE_THREADING_IN_BLOCK;
     hmat::HMatInterface<T> *hmat = (hmat::HMatInterface<T> *)ctx->matrix;
     try {
+        HMAT_ASSERT_MSG(hmat->factorization() != hmat::Factorization::HODLRSYM &&
+                        hmat->factorization() != hmat::Factorization::HODLR,
+                        "Unsupported operation");
         hmat::IndexSet rows(ctx->row_offset, ctx->row_size);
         hmat::IndexSet cols(ctx->col_offset, ctx->col_size);
         typename E<T>::UncompressedBlock view;
@@ -722,6 +738,9 @@ int get_values(struct hmat_get_values_context_t *ctx) {
     // No need to call DISABLE_THREADING_IN_BLOCK here, there is no BLAS call
     hmat::HMatInterface<T> *hmat = (hmat::HMatInterface<T> *)ctx->matrix;
     try {
+        HMAT_ASSERT_MSG(hmat->factorization() != hmat::Factorization::HODLRSYM &&
+                        hmat->factorization() != hmat::Factorization::HODLR,
+                        "Unsupported operation");
         typename E<T>::UncompressedValues view;
         const E<T>& engine = reinterpret_cast<const E<T>&>(hmat->engine());
         view.uncompress(engine.getHandle(),
@@ -819,6 +838,7 @@ static void createCInterface(hmat_interface_t * i)
     i->add_identity = add_identity<T, E>;
     i->init = init<T, E>;
     i->norm = norm<T, E>;
+    i->logdet = logdet<T, E>;
     i->scale = scale<T, E>;
     i->solve_mat = solve_mat<T, E>;
     i->solve_systems = solve_systems<T, E>;
