@@ -71,7 +71,7 @@ void IndexSet::intersection(const IndexSet& s1, const IndexSet& s2) {
 
 DofData::DofData(const DofCoordinates& coordinates, int* group_index)
 {
-  const int size(coordinates.size());
+  int size = coordinates.numberOfDof();
   perm_i2e_ = new int[size];
   perm_e2i_ = new int[size];
   for (int i = 0; i < size; ++i)
@@ -104,24 +104,54 @@ DofData*
 DofData::copy() const
 {
   DofData* result = new DofData(*coordinates_, group_index_);
-  memcpy(result->perm_i2e_, perm_i2e_, sizeof(int) * coordinates_->size());
-  memcpy(result->perm_e2i_, perm_e2i_, sizeof(int) * coordinates_->size());
+  size_t s = sizeof(int) * coordinates_->numberOfDof();
+  memcpy(result->perm_i2e_, perm_i2e_, s);
+  memcpy(result->perm_e2i_, perm_e2i_, s);
   return result;
 }
 
+void ClusterData::moveDoF(int index, ClusterData* right)
+{
+  HMAT_ASSERT(offset_ + size_ == right->offset_ );
+  HMAT_ASSERT(index >= offset_);
+  HMAT_ASSERT(index < offset_ + size_);
+  // Swap degree of freedom and the last element of this bucket
+  std::swap(indices()[index], indices()[offset_ + size_ - 1]);
+  // Make current index set smaller ...
+  size_ -= 1;
+  // ... and expand right sibling
+  right->offset_ -=  1;
+  right->size_ += 1;
+}
+
+void ClusterData::assertValid() {
+  unsigned int n = coordinates()->numberOfDof();
+  std::vector<int> ind(indices(), indices()+n);
+  sort(ind.begin(), ind.end());
+  ind.erase(unique(ind.begin(), ind.end()), ind.end());
+  HMAT_ASSERT(ind.size() == n);
+  HMAT_ASSERT(*std::min_element(ind.begin(), ind.end()) == 0);
+  HMAT_ASSERT(*std::max_element(ind.begin(), ind.end()) == n - 1);
+}
+
 ClusterTree::ClusterTree(const DofData* dofData)
   : Tree<ClusterTree>(NULL)
   , data(dofData)
-  , clusteringAlgoData_(NULL)
-  , admissibilityAlgoData_(NULL)
+  , cache_(NULL)
+{
+}
+
+    ClusterTree::ClusterTree(const DofData* dofData, int offset, int size)
+  : Tree<ClusterTree>(NULL)
+  , data(dofData, offset, size)
+  , cache_(NULL)
 {
 }
 
 ClusterTree::ClusterTree(const ClusterTree& other)
   : Tree<ClusterTree>(NULL)
   , data(other.data)
-  , clusteringAlgoData_(NULL)
-  , admissibilityAlgoData_(NULL)
+  , cache_(NULL)
 {
 }
 
@@ -135,11 +165,13 @@ ClusterTree::~ClusterTree() {
 ClusterTree*
 ClusterTree::slice(int offset, int size) const
 {
+  assert(offset >= 0);
+  assert(size >= 0);
   ClusterTree* result = new ClusterTree(*this);
   result->data.offset_ = offset;
   result->data.size_ = size;
-  result->clusteringAlgoData_ = NULL;
-  result->admissibilityAlgoData_ = NULL;
+  result->depth = depth;
+  result->cache_ = NULL;
   return result;
 }
 
@@ -159,86 +191,93 @@ ClusterTree* ClusterTree::copy(const ClusterTree* copyFather) const {
   return result;
 }
 
-void ClusterTree::sameDepth(const ClusterTree * other) {
-    if(other->isLeaf() || data.size() == 0)
-        return;
-
-    if(isLeaf()) {
-        insertChild(0, new ClusterTree(*this));
-        insertChild(1, slice(data.offset() + data.size(), 0));
-    }
-
-    for(int i = 0; i < other->nrChild(); i++) {
-        for(int j = 0; j < nrChild(); j++) {
-            getChild(j)->sameDepth(other->getChild(i));
-        }
-    }
-}
-
 AxisAlignedBoundingBox::AxisAlignedBoundingBox(const ClusterData& data)
-  : dimension_(data.coordinates()->dimension())
-  , bbMin(new double[dimension_])
-  , bbMax(new double[dimension_])
+    : dimension_(data.coordinates()->dimension())
+    , bb_(new double[2 * dimension_])
 {
-  if (data.size() == 0) return;
-  int* myIndices = data.indices() + data.offset();
-  const double* coord = &data.coordinates()->get(0, 0);
-  memcpy(&bbMin[0], &coord[dimension_*myIndices[0]], sizeof(double) * dimension_);
-  memcpy(&bbMax[0], &coord[dimension_*myIndices[0]], sizeof(double) * dimension_);
+    if (data.size() == 0)
+        return;
+    int* myIndices = data.indices() + data.offset();
+    const DofCoordinates& coords = *data.coordinates();
+    for (unsigned i = 0; i < dimension_; i++) {
+        bb_[i] = coords.spanPoint(myIndices[0], 0, i);
+        bb_[i + dimension_] = bb_[i];
+    }
 
-  for (int i = 0; i < data.size(); ++i) {
-    int index = myIndices[i];
-    const double* p = &coord[dimension_*index];
-    for (int dim = 0; dim < dimension_; ++dim) {
-      bbMin[dim] = std::min(bbMin[dim], p[dim]);
-      bbMax[dim] = std::max(bbMax[dim], p[dim]);
+    for (unsigned i = 1; i < data.size(); ++i) {
+        int dof = myIndices[i];
+        for (unsigned pointId = 0; pointId < coords.spanSize(dof); pointId++)
+            coords.spanAABB(dof, bb_);
     }
-  }
 }
 
-AxisAlignedBoundingBox::AxisAlignedBoundingBox(int dim, const double *bboxMin, const double *bboxMax)
-  : dimension_(dim)
-  , bbMin(new double[dimension_])
-  , bbMax(new double[dimension_])
-{
-  memcpy(&bbMin[0], bboxMin, sizeof(double) * dimension_);
-  memcpy(&bbMax[0], bboxMax, sizeof(double) * dimension_);
-}
-
-AxisAlignedBoundingBox::~AxisAlignedBoundingBox()
-{
-  delete [] bbMin;
-  delete [] bbMax;
+AxisAlignedBoundingBox::~AxisAlignedBoundingBox() {
+    delete[] bb_;
 }
 
 double
-AxisAlignedBoundingBox::diameter() const
+AxisAlignedBoundingBox::diameterSqr() const
 {
   double result = 0.0;
   for(int i = 0; i < dimension_; ++i)
   {
-    double delta = bbMin[i] - bbMax[i];
+    double delta = bbMin()[i] - bbMax()[i];
     result += delta * delta;
   }
 
-  return sqrt(result);
+  return result;
+}
+
+double AxisAlignedBoundingBox::diameter() const {
+    return sqrt(diameterSqr());
+}
+
+double AxisAlignedBoundingBox::extends(int dim) const {
+    return bbMax()[dim] - bbMin()[dim];
+}
+
+int AxisAlignedBoundingBox::greatestDim() const {
+    double dmax = 0;
+    int imax = 0;
+    for(int i = 0; i < dimension_; ++i) {
+        double delta = bbMax()[i] - bbMin()[i];
+        if(delta > dmax) {
+            dmax = delta;
+            imax = i;
+        }
+    }
+    return imax;
 }
 
 double
-AxisAlignedBoundingBox::distanceTo(const AxisAlignedBoundingBox& other) const
+AxisAlignedBoundingBox::distanceToSqr(const AxisAlignedBoundingBox& other) const
 {
   double result = 0.;
   double difference = 0.;
 
   for(int i = 0; i < dimension_; ++i)
   {
-    difference = std::max(0., bbMin[i] - other.bbMax[i]);
+    difference = std::max(0., bbMin()[i] - other.bbMax()[i]);
     result += difference * difference;
-    difference = std::max(0., other.bbMin[i] - bbMax[i]);
+    difference = std::max(0., other.bbMin()[i] - bbMax()[i]);
     result += difference * difference;
   }
 
-  return sqrt(result);
+  return result;
+}
+
+double AxisAlignedBoundingBox::distanceTo(const AxisAlignedBoundingBox& other) const {
+    return sqrt(distanceToSqr(other));
+}
+
+void AxisAlignedBoundingBox::bbMin(const double * bbMin) {
+    for(int i = 0; i < dimension_; ++i)
+        bb_[i] = bbMin[i];
+}
+
+void AxisAlignedBoundingBox::bbMax(const double * bbMax) {
+    for(int i = 0; i < dimension_; ++i)
+        bb_[i + dimension_] = bbMax[i];
 }
 
 }  // end namespace hmat
