@@ -24,8 +24,7 @@
   \ingroup HMatrix
   \brief Context manager used for the tracing functionnality.
 */
-#ifndef _CONTEXT_HPP
-#define _CONTEXT_HPP
+#pragma once
 
 #include "hmat/config.h"
 #include "common/chrono.h"
@@ -78,6 +77,7 @@ namespace trace {
         - between 1 and n_workers (included) in parallel regions
    */
   void setNodeIndexFunction(int (*nodeIndexFunc)());
+  int currentNodeIndex();
 
   class Node {
   public:
@@ -85,7 +85,7 @@ namespace trace {
     static bool enabled;
   private:
     /// Unique name for the context.
-    const char* name;
+    const char* name_;
     /// Tracing data associated with this node.
     NodeData data;
     /// Parent node. NULL for a root.
@@ -99,7 +99,7 @@ namespace trace {
   public:
     /** Enter a context noted by a name.
      */
-    static void enterContext(const char* name);
+    static void enterContext(const char* name_);
     /** Leave the current context.
      */
     static void leaveContext();
@@ -143,19 +143,19 @@ public:
   }
 };
 
+#define tracing_set_worker_index_func(f) trace::setNodeIndexFunction(f)
+
 #ifdef HAVE_CONTEXT
 
 // Since 'enable' is not used anywhere, this macro probably does nothing.
 #define DISABLE_CONTEXT_IN_BLOCK DisableContextInBlock dummyDisableContextInBlock
 
-#define tracing_set_worker_index_func(f) trace::setNodeIndexFunction(f)
 #define enter_context(x) trace::Node::enterContext(x)
 #define leave_context() trace::Node::leaveContext()
 #define increment_flops(x) trace::Node::incrementFlops(x)
 #define tracing_dump(x) trace::Node::jsonDumpMain(x)
 
 #else
-#define tracing_set_worker_index_func(f) do {} while (0)
 #define enter_context(x) do { hmat::ignore_unused_arg(x); } while(0)
 #define leave_context()  do {} while(0)
 #define increment_flops(x) do { hmat::ignore_unused_arg(x); } while(0)
@@ -184,4 +184,3 @@ public:
 #define DECLARE_CONTEXT Context __reserved_ctx(__func__)
 #endif
 
-#endif
