@@ -28,15 +28,26 @@
 #include "common/my_assert.h"
 #include <algorithm>
 
-#ifdef __GLIBC__
+#if defined(HAVE_JEMALLOC) && defined(__linux__)
+#define JEMALLOC_NO_DEMANGLE
+#include <jemalloc/jemalloc.h>
+#endif
+
+#if defined(__GLIBC__) && !defined(HAVE_JEMALLOC)
 #include <malloc.h>
 // Do not care about thread safety. This is an acceptable approximation.
+#if __GLIBC_PREREQ(2,33)
+static struct mallinfo2 global_mallinfo;
+#else
 static struct mallinfo global_mallinfo;
-static int mallinfo_counter;
 #endif
+#endif
+static int mallinfo_counter;
 static int write_counter;
 static int mallinfo_sampling;
 static int write_sampling;
+// -1 unsigned is the max value for size_t
+static size_t jemalloc_heapdump_trigger = (size_t)-1;
 
 namespace hmat {
 
@@ -46,10 +57,19 @@ static size_t get_res_mem(void *)
     size_t resident = 0;
 #ifdef __linux__
     FILE * statm_file = fopen("/proc/self/statm", "r");
-    fscanf(statm_file, "%*s %lu", &resident);
+    int r = fscanf(statm_file, "%*s %zu", &resident);
+    HMAT_ASSERT(r == 1);
     fclose(statm_file);
+    resident *= 4096;
+  #ifdef HAVE_JEMALLOC
+    if(resident >= jemalloc_heapdump_trigger) {
+        // It would be to slow to do multiple heap dump
+        jemalloc_heapdump_trigger = (size_t)-1;
+        je_mallctl("prof.dump", NULL, NULL, NULL, 0);
+    }
+  #endif
 #endif
-    return resident * 4096;
+    return resident;
 }
 #endif
 
@@ -58,6 +78,8 @@ MemoryInstrumenter::MemoryInstrumenter(): enabled_(false) {
     write_sampling = ws ? atoi(ws) : 1;
     char * mi = getenv("HMAT_MEMINSTR_MI");
     mallinfo_sampling = mi ? atoi(mi) : 100;
+    char * ht = getenv("HMAT_HEAPDUMP");
+    jemalloc_heapdump_trigger = ht ? atol(ht) : jemalloc_heapdump_trigger;
     addType("Time", false);
 #if __GNUC__
     addType("FullMatrix", false);
@@ -91,13 +113,13 @@ MemoryInstrumenter::MemoryInstrumenter(): enabled_(false) {
 }
 
 void MemoryInstrumenter::setFile(const std::string & filename) {
+    mallinfo_counter = 0;
 #ifdef HMAT_MEM_INSTR
     filename_ = filename;
     output_ = fopen(filename.c_str(), "w+");
     HMAT_ASSERT_MSG(output_ != NULL, "Cannot open %s", filename.c_str());
     start_ = now();
     fullMatrixMem_ = 0;
-    mallinfo_counter = 0;
 
     FILE * labelsf = fopen((filename_+".labels").c_str(), "w");
     for(int i = 0; i < labels_.size(); i++) {
@@ -139,10 +161,14 @@ void MemoryInstrumenter::allocImpl(mem_t size, char type) {
         if(type > 0)
             buffer[type] = size;
 
-#ifdef __GLIBC__
+#if defined(__GLIBC__) && !defined(HAVE_JEMALLOC)
         mallinfo_counter ++;
         if(mallinfo_counter >= mallinfo_sampling) {
+#if __GLIBC_PREREQ(2,33)
+            global_mallinfo = mallinfo2();
+#else
             global_mallinfo = mallinfo();
+#endif
             mallinfo_counter = 0;
         }
         int k = 3;
