@@ -61,10 +61,10 @@ using std::min;
 using std::max;
 
 namespace {
-struct EnvVar {
+struct EnvVarCP {
   /** */
   int logAcaPartialMinSize;
-  EnvVar() {
+  EnvVarCP() {
 	// Enable ACA partial verbose mode for blocks larger than a given size.
     const char * logAcaStr = getenv("HMAT_LOG_ACA_PARTIAL");
     if(logAcaStr == nullptr) {
@@ -74,7 +74,7 @@ struct EnvVar {
     }
   }
 };
-static const EnvVar env;
+static const EnvVarCP envCP;
 } // namespace
 
 namespace hmat {
@@ -389,7 +389,7 @@ doCompressionAcaPartial(const ClusterAssemblyFunction<T>& block, double compress
   const int rowCount = block.rows->size();
   const int colCount = block.cols->size();
   int maxK = min(rowCount, colCount);
-  bool verbose = maxK > env.logAcaPartialMinSize;
+  bool verbose = maxK > envCP.logAcaPartialMinSize;
   // Contains false for the rows that were already used as pivot
   vector<bool> rowFree(rowCount, true);
   int rowPivotCount = 0;
@@ -398,6 +398,15 @@ doCompressionAcaPartial(const ClusterAssemblyFunction<T>& block, double compress
   vector<Vector<dp_t>*> aCols;
   vector<Vector<dp_t>*> bCols;
 
+  if (block.info.is_guaranteed_null_row) {
+    for(int i = 0; i < rowCount; ++i)
+      rowFree[i] = !block.info.is_guaranteed_null_row(&block.info, i, block.stratum);
+  }
+  if (block.info.is_guaranteed_null_col) {
+    for(int i = 0; i < colCount; ++i)
+      colFree[i] = !block.info.is_guaranteed_null_col(&block.info, i, block.stratum);
+  }
+
   int row_index = 0;
   int J = 0;
   int k = 0;
@@ -547,6 +556,15 @@ doCompressionAcaPlus(const ClusterAssemblyFunction<T>& block, double compression
   vector<bool> rowFree(rowCount, true), colFree(colCount, true);
   vector<Vector<dp_t>*> aCols, bCols;
 
+  if (block.info.is_guaranteed_null_row) {
+    for(int i = 0; i < rowCount; ++i)
+      rowFree[i] = !block.info.is_guaranteed_null_row(&block.info, i, block.stratum);
+  }
+  if (block.info.is_guaranteed_null_col) {
+    for(int i = 0; i < colCount; ++i)
+      colFree[i] = !block.info.is_guaranteed_null_col(&block.info, i, block.stratum);
+  }
+
   j_ref = findCol(block, colFree, aRef);
   if (j_ref == -1) {
 	// The block is completely zero.
@@ -623,8 +641,8 @@ doCompressionAcaPlus(const ClusterAssemblyFunction<T>& block, double compression
     // Update of a_ref and b_ref
     aRef.axpy(-(*bCols[k - 1])[j_ref], aCols[k - 1]);
     bRef.axpy(-(*aCols[k - 1])[i_ref], bCols[k - 1]);
-    const bool needNewA = aRef.isZero() || (j_star == j_ref);
-    const bool needNewB = bRef.isZero() || (i_star == i_ref);
+    const bool needNewA = (j_star == j_ref) || aRef.isZero();
+    const bool needNewB = (i_star == i_ref) || bRef.isZero();
 
     // If the row or the column of reference have been already chosen as pivot,
     // we can not keep it and then we take one or two others.
