@@ -25,6 +25,34 @@
 
 namespace hmat {
 
+template<>
+ScalarArray<D_t>* fromDoubleScalarArray(ScalarArray<D_t>* d, bool) {
+  return d;
+}
+template<>
+ScalarArray<Z_t>* fromDoubleScalarArray(ScalarArray<Z_t>* d, bool) {
+  return d;
+}
+
+template<typename T>
+ScalarArray<T>* fromDoubleScalarArray(ScalarArray<typename Types<T>::dp>* d, bool del) {
+  if (!d) {
+    return NULL;
+  }
+  ScalarArray<T>* result = new ScalarArray<T>(d->rows, d->cols);
+  assert(result);
+  for (int j = 0; j < d->cols; ++j)
+    for (int i = 0; i < d->rows; ++i)
+      result->get(i, j) = T(d->get(i, j));
+  result->setOrtho(d->getOrtho());
+  if (del)
+    delete d;
+  return result;
+}
+
+template ScalarArray<S_t>* fromDoubleScalarArray(ScalarArray<Types<S_t>::dp>* d, bool);
+template ScalarArray<C_t>* fromDoubleScalarArray(ScalarArray<Types<C_t>::dp>* d, bool);
+
 template<>
 FullMatrix<D_t>* fromDoubleFull(FullMatrix<D_t>* f) {
   return f;
@@ -36,18 +64,13 @@ FullMatrix<Z_t>* fromDoubleFull(FullMatrix<Z_t>* f) {
 
 template<typename T>
 FullMatrix<T>* fromDoubleFull(FullMatrix<typename Types<T>::dp>* f) {
-  if (!f) {
+  if (!f)
     return NULL;
-  }
-  FullMatrix<T>* result = new FullMatrix<T>(f->rows, f->cols);
-  assert(result);
-  assert(f->lda == f->rows);
-  const size_t size = ((size_t) f->rows) * f->cols;
-  T* const r = result->m;
-  const typename Types<T>::dp* m = f->m;
-  for (size_t i = 0; i < size; ++i) {
-    r[i] = T(m[i]);
-  }
+  FullMatrix<T>* result = new FullMatrix<T>(f->rows_, f->cols_);
+  for (int j = 0; j < f->cols(); ++j)
+    for (int i = 0; i < f->rows(); ++i)
+      result->get(i, j) = T(f->get(i, j));
+  result->data.setOrtho(f->data.getOrtho());
   delete f;
   return result;
 }
@@ -63,12 +86,11 @@ template<> RkMatrix<Z_t>* fromDoubleRk(RkMatrix<Z_t>* rk) {
 }
 
 template<typename T> RkMatrix<T>* fromDoubleRk(RkMatrix<typename Types<T>::dp>* rk) {
-  RkMatrix<T>* result = new RkMatrix<T>(fromDoubleFull<T>(rk->a),
+  RkMatrix<T>* result = new RkMatrix<T>(fromDoubleScalarArray<T>(rk->a),
                                         rk->rows,
-                                        fromDoubleFull<T>(rk->b),
-                                        rk->cols,
-                                        rk->method);
-  rk->a= NULL;
+                                        fromDoubleScalarArray<T>(rk->b),
+                                        rk->cols);
+  rk->a = NULL; // because rk->a and rk->b have allready been deleted in fromDoubleScalarArray
   rk->b = NULL;
   delete rk;
   return result;
