@@ -627,13 +627,15 @@ public:
   static bool validateNullRowCol;
   /// Validate the rk-matrices after compression
   static bool validateCompression;
+  /// Validate the rk-matrices after recompression
+  static bool validateRecompression;
   /// For blocks above error threshold, re-run the compression algorithm
   static bool validationReRun;
   /// For blocks above error threshold, dump the faulty block to disk
   static bool validationDump;
   /// Error threshold for the compression validation
   static double validationErrorThreshold;
-  short isUpper:1, isLower:1,       /// symmetric, upper or lower stored
+  unsigned short isUpper:1, isLower:1,       /// symmetric, upper or lower stored
        isTriUpper:1, isTriLower:1, /// upper/lower triangular
        keepSameRows:1, keepSameCols:1,
        temporary_:1, ownRowsClusterTree_:1, ownColsClusterTree_:1;
@@ -667,6 +669,8 @@ public:
   }
 
   void full(FullMatrix<T> * m) {
+      assert(m == nullptr || *m->rows_ == *this->rows());
+      assert(m == nullptr || *m->cols_ == *this->cols());
       full_ = m;
       rank_ = FULL_BLOCK;
   }
