@@ -165,7 +165,7 @@ private:
     void getNullValues() {
         for(IndiceIt r = this->rowStart_; r != this->rowEnd_; ++r) {
             for(IndiceIt c = this->colStart_; c != this->colEnd_; ++c) {
-                getValue(r, c, Constants<T>::zero);
+                getValue(r, c, 0);
             }
         }
     }
@@ -188,11 +188,11 @@ private:
 
 public:
     void getLeafValues() {
-        if (this->matrix_->isNull()) {
+        if (this->matrix().isNull()) {
             getNullValues();
-        } else if (this->matrix_->isRkMatrix()) {
+        } else if (this->matrix().isRkMatrix()) {
             getRkValues();
-        } else if (this->matrix_->isFullMatrix()) {
+        } else if (this->matrix().isFullMatrix()) {
             getFullValues();
         } else {
             assert(false);
